@@ -148,11 +148,11 @@ class APTPlugin(Plugin):
             else:
                 if name["name"] in self._ignore():
                     logging.debug(f"Package {name} is part of the base system.")
-                targetted.setdefault(name.get("options") or {}, []).append(name)
+                targetted.setdefault(tuple(name.get("options") or ()), []).append(name)
         for options, packages in targetted.items():
             sudo().cc(
                 ["apt-get", "install", "-y"]
-                + options
+                + list(options)
                 + [package["name"] for package in packages]
             )
         for package in manual:
